Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(805)

Unified Diff: content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc

Issue 9251022: Fix JavaBridgeDispatcherHost to use WebContents rather than TabContents (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc
diff --git a/content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc b/content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc
index 34193e0b57164f99391993c8c154614b0814184b..f76cbd5742db85249ddc972306da973ac730f4f6 100644
--- a/content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc
+++ b/content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.cc
@@ -6,12 +6,11 @@
#include "base/utf_string_conversions.h"
#include "content/browser/renderer_host/java/java_bridge_dispatcher_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebBindings.h"
JavaBridgeDispatcherHostManager::JavaBridgeDispatcherHostManager(
- TabContents* tab_contents)
- : content::WebContentsObserver(tab_contents) {
+ content::WebContents* web_contents)
+ : content::WebContentsObserver(web_contents) {
}
JavaBridgeDispatcherHostManager::~JavaBridgeDispatcherHostManager() {
@@ -70,7 +69,7 @@ void JavaBridgeDispatcherHostManager::RenderViewDeleted(
void JavaBridgeDispatcherHostManager::WebContentsDestroyed(
content::WebContents* web_contents) {
// When the tab is shutting down, the TabContents clears its observers before
// it kills all of its RenderViewHosts, so we won't get a call to
// RenderViewDeleted() for all RenderViewHosts.
instances_.clear();
@@ -70,7 +69,7 @@ void JavaBridgeDispatcherHostManager::RenderViewDeleted(
void JavaBridgeDispatcherHostManager::WebContentsDestroyed(
content::WebContents* web_contents) {
- // When the tab is shutting down, the TabContents clears its observers before
+ // When the tab is shutting down, the WebContents clears its observers before
// it kills all of its RenderViewHosts, so we won't get a call to
// RenderViewDeleted() for all RenderViewHosts.
« no previous file with comments | « content/browser/renderer_host/java/java_bridge_dispatcher_host_manager.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698